# Maxima Tool

Created by Jan Kotanski, last modified on May 10, 2019 14:52

Maxima Tool points pixels with the highest intensity

- Maxima: a list of pixels with the highest intensity, i.e. No: intensity_value at (x, y)
  A number of maxima to find can be selected in a spin-box on the right
- Geometry: detector geometry parameters. They can be pass in both ways via LavueController tango server
- theta angles or q-space selects the radial transformation